package reddit_api_kernel

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Thing.More_commentsSource

include S
Sourcetype t
include Ppx_sexp_conv_lib.Sexpable.S with type t := t
Sourceval t_of_sexp : Sexplib0__.Sexp.t -> t
Sourceval sexp_of_t : t -> Sexplib0__.Sexp.t
include Core_kernel.Bin_prot.Binable.S with type t := t
include Bin_prot.Binable.S_only_functions with type t := t
Sourceval bin_size_t : t Bin_prot.Size.sizer
Sourceval bin_write_t : t Bin_prot.Write.writer
Sourceval bin_read_t : t Bin_prot.Read.reader
Sourceval __bin_read_t__ : (int -> t) Bin_prot.Read.reader

This function only needs implementation if t exposed to be a polymorphic variant. Despite what the type reads, this does *not* produce a function after reading; instead it takes the constructor tag (int) before reading and reads the rest of the variant t afterwards.

Sourceval bin_shape_t : Bin_prot.Shape.t
Sourcemodule Id : Id36.S
include Json_object.S_with_fields with type t := t
include Json_object_intf.S with type t := t
Sourceval get_field : t -> string -> Json.t option
Sourceval get_field_exn : t -> string -> Json.t
include Json_object.S_with_kind with type t := t
include Json_object_intf.S with type t := t
Sourceval of_json : Json.t -> t
Sourceval to_json : t -> Json.t
Sourceval kind : string
Sourceval id : t -> Id.t
Sourcemodule Details : sig ... end
Sourceval count : t -> int
Sourceval details : t -> Details.t